@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: persistent-template
 version: 2.1.5
-id: persistent-template-2.1.5-843c6c1cb8c608f5d7b0340a1ba98852
-key: persi_L1sGdgfttEoLNheDOxYfGO
+id: persistent-template-2.1.5-b75d3f03ad073bca4fe2b675c1178327
+key: persi_CqmvJbisqq4Gs767joqCNx
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
 stability: Stable
@@ -20,10 +20,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-template-2.1.5
 library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-template-2.1.5
 data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-template-2.1.5
-hs-libraries: HSpersistent-template-2.1.5-L1sGdgfttEoLNheDOxYfGO
+hs-libraries: HSpersistent-template-2.1.5-CqmvJbisqq4Gs767joqCNx
 depends:
-    aeson-0.10.0.0-3aa334e096178e3f732c7fe0cfda35e7
-    aeson-compat-0.3.1.0-31f7363b7ec2a62ab03ab2396f0de1f2
+    aeson-0.11.0.0-3b69ab8a9952fc7c94fde12b431d717b
+    aeson-compat-0.3.1.0-477156b04fb574ca75dcbd9c0a3687a2
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
@@ -32,7 +32,7 @@ depends:
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
     monad-logger-0.3.18-1a8cc90bb0cf2afc03da9e875eb23203
     path-pieces-0.2.1-c4c6ea4593a7da7123f92fac6c85ebd3
-    persistent-2.2.4-7bfa93ca2781b33384883da4115f96aa
+    persistent-2.2.4-bd2986a850822d0f7f277144476772ce
     tagged-0.8.3-aa128de4449752177a05765fb0ce3959
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
